@@ -67,10 +67,10 @@ class Container(BaseContainer, ContextInstanceMixin):
                 dependency_wrappers.append(dependency_wrapper.target)
         return dependency_wrappers
 
-    def _get_implementation_attr(self, signatures: inspect.Signature) -> Dict[str, Any]:
-        """Get resolved object attributes"""
+    def _get_implementation_attr(self, signature: inspect.Signature) -> Dict[str, Any]:
+        """Get resolved signature attributes"""
         callable_object_arguments = {}
-        for attr_name, parameter in signatures.parameters.items():
+        for attr_name, parameter in signature.parameters.items():
             if attr_name == "self":
                 continue
 
@@ -102,6 +102,10 @@ class Container(BaseContainer, ContextInstanceMixin):
             implementation = implementation(**attr)
         return implementation
 
+    def get_target_attributes(self, target: Any) -> Dict[str, Any]:
+        """Get resolved object attributes"""
+        return self._get_implementation_attr(get_typed_signature(target))
+
     def _get_raw_dependency(self, annotation: Any) -> Iterator[DependencyWrapper]:
         """Get unresolved object/class"""
         context_dependency_storage = self._context_dependency_storage.get(None)
@@ -121,3 +125,6 @@ class Container(BaseContainer, ContextInstanceMixin):
             for dependency_wrapper in storage:
                 if _check_annotation(annotation, dependency_wrapper.type_):
                     yield dependency_wrapper
+
+    def __len__(self) -> int:
+        return len(self._dependency_storage) + len(self._context_dependency_storage.get([]))
