@@ -1,7 +1,7 @@
 from typing import Any
 
-from pydantic import BaseModel
 from enum import IntEnum
+from dataclasses import dataclass
 
 
 class Scope(IntEnum):
@@ -9,7 +9,8 @@ class Scope(IntEnum):
     TRANSIENT: int = 1
 
 
-class DependencyWrapper(BaseModel):
+@dataclass(frozen=True)
+class DependencyWrapper:
     type_: Any
     target: Any
     scope: int = Scope.TRANSIENT
